import React, { useContext, useEffect } from "react";
import { styled } from "@mui/material/styles";
import { Paper, Grid, useTheme } from "@mui/material";
import { GlobalAppBarContext } from "@ess-ics/ce-ui-common";
import { RootContainer } from "../../components/common/Container/RootContainer";
import ActiveIOCChart from "../../components/statistics/ActiveIOCChart";
import DeploymentLineChart from "../../components/statistics/DeploymentLineChart";
import { HostStatistics } from "../../components/statistics/HostStatistics";
import { IOCStatistics } from "../../components/statistics/IOCStatistics";
import OperationChart from "../../components/statistics/OperationChart/OperationChart";
import { applicationTitle } from "../../components/common/Helper";
import { apiContext } from "../../api/DeployApi";
import { useAPIMethod } from "@ess-ics/ce-ui-common";

const PREFIX = "StatisticsView";

const classes = {
  paper: `${PREFIX}-paper`
};

const StyledRootContainer = styled(RootContainer)(({ theme }) => ({
  [`& .${classes.paper}`]: {
    padding: theme.spacing(4)
  }
}));

export function StatisticsView() {
  const { setTitle } = useContext(GlobalAppBarContext);
  useEffect(() => setTitle(applicationTitle("Statistics")), [setTitle]);
  const client = useContext(apiContext);

  const theme = useTheme();

  const { value: iocsOverTime, wrapper: getIocsOverTime } = useAPIMethod({
    fcn: client.apis.Statistics.activeIocHistory,
    call: false
  });

  const { value: operationStatistics, wrapper: getOperationStatistics } =
    useAPIMethod({
      fcn: client.apis.Statistics.operationHistory,
      call: false
    });

  return (
    <StyledRootContainer>
      <Grid
        container
        spacing={theme.spacing(0.5)}
      >
        <Grid
          item
          xs={6}
        >
          <IOCStatistics />
        </Grid>

        <Grid
          item
          xs={6}
        >
          <HostStatistics />
        </Grid>

        <Grid
          item
          xs={12}
        >
          <Paper className={classes.paper}>
            <OperationChart
              title="Operations over time"
              iocDeployments={operationStatistics}
              getIOCDeployments={getOperationStatistics}
            />
          </Paper>
        </Grid>
        <Grid
          item
          xs={12}
        >
          <Paper className={classes.paper}>
            <ActiveIOCChart title="Number of IOCs detected per network" />
          </Paper>
        </Grid>
        <Grid
          item
          xs={12}
        >
          <Paper className={classes.paper}>
            <DeploymentLineChart
              title="Number of IOCs detected over time"
              chartLabel="Active IOCs over time"
              iocDeployments={iocsOverTime}
              getIOCDeployments={getIocsOverTime}
            />
          </Paper>
        </Grid>
      </Grid>
    </StyledRootContainer>
  );
}
